Changelog
=========

master
------


v0.1.2
------

- Fixed missing ``esgf_scraper.ext`` module in source distributions
- (`#6 <https://gitlab.com/magicc/esgf_scraper/merge_requests/6>`_) Added ``database_url`` configuration value to specify a custom database location.

v0.1.1
------

- Fix versioning issue

v0.1.0
------

- (`#5 <https://gitlab.com/magicc/esgf_scraper/merge_requests/5>`_) Using isort
- (`#4 <https://gitlab.com/magicc/esgf_scraper/merge_requests/4>`_) Began enforcing code standards
- (`#3 <https://gitlab.com/magicc/esgf_scraper/merge_requests/3>`_) Added autogenerated documentation
- (`#2 <https://gitlab.com/magicc/esgf_scraper/merge_requests/2>`_) Began using Gitlab's CI for running tests on every push
- Initial development

